@@ -13,7 +13,10 @@ sub envs
     $cnt++;
 
     warn( "Site1 App1 $cnt\n" ) if $ENV{APP_ENV_DEBUG};
-    return { %ENV, Site1_App1 => $cnt, %{$opt} };
+    return { %ENV, 
+             Site1_App1 => $cnt,
+             Site1_App1_v1 => $cnt,
+             %{$opt} };
 }
 
 sub reset
